import { OnInit } from '@angular/core';
import { IChatDetailMessage } from '../../dto/ichat-detail-message';
import { Fecha } from '../../../utilitario/fecha/fecha';
import { EMessageState } from '../../dto/emessage-state';
import { EMessageType } from '../../dto/emensaje-type';
/**
 * Componente que muestra los mensajes de un chat
 */
export declare class ChatDetailMessageComponent implements OnInit {
    /**
     * Variable que Contiene todos los mensajes de un chat
     */
    messages: IChatDetailMessage[];
    /**
     * Variable para usar enum en html
     */
    EMessageState: typeof EMessageState;
    /**
     * Variable en la cual trabajaremos las fechas
     */
    date: Fecha;
    /**
     * @ignore
     */
    constructor();
    /**
     * @ignore
     */
    ngOnInit(): void;
    /**
     * Si el index es 0 a la fecha enviada se le restara un dia para que retorne true y genere una linea
     * Si el index es mayor a 0 tomara la fecha del mensaje anterior y la comparara
     * si se envia un undefined un null o una fecha invalidad no imprimira linea
     * @param date recibe la fecha del mensaje
     * @param index index del elemento en el arreglo
     * @returns si debe mostrar una linea o no
     */
    dayLine(dateString: string, index: number): boolean;
    /**
     * Compara los dias entre la fecha actual y la enviada para insertar el texto en el chat
     * @param date fecha del mensaje
     */
    dayDifference(date: Date): string;
    /**
     * Validamos si el tipo de mensaje es enviado
     * @param state estado actual del mensaje
     * @param messageType enviado o recibido
     * @param stateSearch tipo que se consulta
     */
    messageState(state: EMessageState, messageType: EMessageType, stateSearch: EMessageState): boolean;
    /**
     * Insertamos el estilo al mensaje dependiendo el tipo del mensaje
     * @param messageType si es recibido o enviado
     */
    chooseStyle(messageType: EMessageType): string;
    /**
     * Validaremos si debe mostrar el mensaje o no
     * @param message mensaje recibido
     */
    validateMessage(message: string): boolean;
    /**
     * Validaremos si debe mostrar imagen o no
     * si mostramos una imagen pasaremos el Filelist a DataUrl
     * @param image imagen en el mensaje
     */
    validateImage(message: IChatDetailMessage): boolean;
    /**
     * Parseara el data enviado a una url
     * @param image Ruta de la image o el archivo de la imagen
     * @returns la imagen
     */
    messageImageUrl(image: any, message: IChatDetailMessage): any;
}
